# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 23:47:18 2016

Library of patch circles + dummy circle.

Ing.,Mgr. (MSc.) Jan Cimbálník
Biomedical engineering
International Clinical Research Center
St. Anne's University Hospital in Brno
Czech Republic
&
Mayo systems electrophysiology lab
Mayo Clinic
200 1st St SW
Rochester, MN
United States
"""

# %% Imports

from .utils import *

import matplotlib.pyplot as plt
import numpy as np


# %% Add custom patches

def patch_circ(nodes, groupby, data, r, cmap='jet', patch_height=1, ax=None,
               group_order=None, group_colors=None, labels=False,
               headlayer=None):

    """
    Creates circle with each node as a patch colored according to its group.

    Parameters:
    -----------
    nodes - column name with node names\n
    groupby - column name with node groups\n
    data - pandas dataframe\n
    r - radius of the circle\n
    cmap - matplotlib cmap for colorcoding\n
    patch_height - height of the patch\n
    ax - axes to which the circle is plotted\n
    group_order - list with group names with set order\n
    group_colors - colors for groups - standar matplotlib coding\n
    create_labels - wether to create node and group labels\n
    headlayer - leading layer where node positions are specified\n

    Returns:
    --------
    ax - plot axes
    layer - layer object
    """

    # Groups
    if group_order is None:
        groups = list(data[groupby].unique())
    else:
        groups = group_order

    # Create colors if None are set
    if group_colors is None:
        # Create colormap
        colormap = plt.get_cmap(cmap)
        group_color_vals = np.linspace(0, 1, len(groups), endpoint=False)
        group_colors = colormap(group_color_vals)

    # Create node list
    data.loc[:, 'rel_vals'] = 0
    if headlayer is None:
        node_list, node_width = create_node_list(nodes, data, r,
                                                 groupby=groupby)
    else:
        node_list = headlayer.node_list
        node_list = reuse_nodes(node_list, nodes, data, r)
        node_width = headlayer.node_width

    # If no axis is passed, create one
    if ax is None:
        plt.figure(facecolor='w')
        ax = plt.subplot(111, projection='polar')
        ax.spines['polar'].set_visible(False)

    for node in node_list:
        node_group = data.loc[(data[nodes] == node.label), groupby].values[0]
        node.color = group_colors[groups.index(node_group)]

        # Create node in plot

        bar = ax.bar(node.position[0], patch_height, width=node_width,
                     bottom=r, color=node.color, edgecolor=node.color,
                     alpha=node.opacity)[0]

        node.patch = bar

    if labels:
        create_labels(node_list, node_width, ax)
        if any([x.group for x in node_list]):
            create_group_labels(node_list, node_width, ax)

    # In the end create layer instance
    layer = CircLayer('hist_circo', r, patch_height, node_list, node_width)

    return ax, layer


# %% Dummy circ

def dummy_circ(nodes, data, orderby=None, groupby=None,
               ax=None, headlayer=None):

    """
    Creates a dummy circle that is not visible. Serves for creation of node
    locations and groups.

    Parameters:
    -----------
    nodes - column name with node names\n
    data - pandas dataframe\n
    orderby - column name by which the nodes are ordered\n
    groupby - column name with node groups\n
    ax - axes to which the circle is plotted\n
    headlayer - leading layer where node positions are specified\n

    Returns:
    --------
    ax - plot axes
    layer - layer object
    """

    # Create node list
    data['rel_vals'] = 0
    if headlayer is None:
        node_list, node_width = create_node_list(nodes, data, 0,
                                                 orderby=orderby,
                                                 groupby=groupby)
    else:
        node_list = headlayer.node_list
        node_list = reuse_nodes(node_list, nodes, data, 0)
        node_width = headlayer.node_width

    # In the end create layer instance
    layer = CircLayer('dummy_circ', 0, 0, node_list, node_width)

    return ax, layer



# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 23:34:16 2016

Library of objects and internal functions

Ing.,Mgr. (MSc.) Jan Cimbálník
Biomedical engineering
International Clinical Research Center
St. Anne's University Hospital in Brno
Czech Republic
&
Mayo systems electrophysiology lab
Mayo Clinic
200 1st St SW
Rochester, MN
United States
"""

# %% Imports


import pandas as pd
import matplotlib.pyplot as plt
import numpy as np

# %% Node class


class CircNode:

    def __init__(self, position, label, group=None):
        self.position = position
        self.label = label
        self.group = group
        self.relative_value = 0
        self.color = "b"
        self.opacity = 1
        self.patch = None


# %% Connection class

class CircConn:

    def __init__(self, start_node, end_node):
        self.start_node = start_node
        self.end_node = end_node
        self.start_point = []
        self.end_point = []
        self.relative_value = 0
        self.color = "b"
        self.opacity = 1
        self.linewidth = 1
        self.patch = None

# %% Layer class


class CircLayer:

    def __init__(self, l_type, r, span, node_list=None, node_width=0,
                 conn_list=None):
        self.type = l_type
        self.r = r
        self.span = span
        self.node_list = node_list
        self.node_width = node_width
        self.conn_list = conn_list
        self.cmap = 'jet'  # Is this neccessary?
        self.sublayer = None  # This is only for heatmap
        self.labels = False


# %% Create labels

# TODO - make this a node funciton ?

def create_labels(node_list, node_width, ax):

    # Remove original ticks
    plt.xticks([])
    plt.yticks([])

    # Draw node labels
    for node in node_list:
        angle_deg = 180 * (node.position[0] + node_width/2) / np.pi
        angle_rad = (node.position[0] + node_width/2)

        if angle_deg >= 270 or angle_deg <= 90:
            ha = 'left'
        else:
            # Flip the label, so text is always upright
            angle_deg += 180
            ha = 'right'
        ax.text(angle_rad, ax.get_ylim()[1]+0.4, node.label,
                rotation=angle_deg, rotation_mode='anchor',
                horizontalalignment=ha, verticalalignment='center')


def create_group_labels(node_list, node_width, ax):

    # Remove original ticks
    plt.xticks([])
    plt.yticks([])

    # Get groups
    group_list = list(set([node.group for node in node_list]))

    for group in group_list:
        group_thetas = [node.position[0] for node in node_list
                        if node.group == group]
        group_start = min(group_thetas)
        group_end = max(group_thetas)
        group_width = group_end - group_start

        angle_deg = 180 * (group_start + group_width/2 + node_width/2) / np.pi
        angle_rad = (group_start + group_width/2 + node_width/2)

        if angle_deg >= 270 or angle_deg <= 90:
            ha = 'left'
        else:
            # Flip the label, so text is always upright
            angle_deg += 180
            ha = 'right'

        ax.text(angle_rad, ax.get_ylim()[1]+2, group,
                rotation=angle_deg, rotation_mode='anchor',
                horizontalalignment=ha, verticalalignment='center')

# %% Node operations


def create_node_list(nodes, data, r, orderby=None, groupby=None,
                     sublayers=None, r_increment=0.1):

    # TODO - needs incremet for heatmap

    # Create groups if set
    N_groups = 0
    if groupby is not None:
        # Reorder the dataframe to match the groups
        if orderby is not None:
            data = data.sort_values(by=[groupby, orderby])
        else:
            data = data.sort_values(by=[groupby])

        group_list = list(data[groupby].unique())
        N_groups = len(group_list)  # This number is equal to number of gaps

    N = len(data[nodes].unique())  # This should be the number of channels
    thetas = np.linspace(0.0, 2*np.pi, N + N_groups, endpoint=False)
    node_width = 2 * np.pi / (N + N_groups)

    node_list = []
    for node_idx, node_label in enumerate(data[nodes].unique()):
        if groupby is not None:
            node_groups = data[(data[nodes] == node_label)][groupby].unique()
            if len(node_groups) > 1:
                print('Node belongs to more than one group!!!')
            group_idx = group_list.index(node_groups)

            node_idx += group_idx
            group = group_list[group_idx]
        else:
            group = None

        # FIXME: There has to be a better way to deal withe heatmap problem
        if sublayers is None:

            # Create node instance
            node = CircNode([thetas[node_idx], r], node_label)
            node.group = group
            node.relative_value = data[(data[nodes] == node_label)]['rel_vals']

            # Add to node list
            node_list.append(node)
        else:
            i = 0
            for sublayer in data[sublayers].unique():
                row = r_increment * i
                # Create node instance
                node = CircNode([thetas[node_idx], r + row], node_label)
                node.group = group
                rel_val = data[(data[nodes] == node_label) &
                               (data[sublayers] == sublayer)]['rel_vals']
                # In case the value is not in the dataframe
                if len(rel_val):
                    node.relative_value = rel_val
                else:
                    node.relative_value = 0

                i += 1

                # Add to node list
                node_list.append(node)

    return node_list, node_width


def reuse_nodes(node_list, nodes, data, r, sublayers=None,
                r_increment=0.1):

    # Take care of nodes coming from heatmap - takes only inner circle
    min_val = min([x.position[1] for x in node_list])
    node_list = [x for x in node_list if x.position[1] == min_val]

    new_node_list = []
    for node in node_list:

        # FIXME: There has to be a better way to deal withe heatmap problem
        if sublayers is None:

            # Create node instance
            new_node = CircNode([node.position[0], 0], node.label,
                                  group=node.group)
            new_node.position[1] = r
            rel_val = data[(data[nodes] == new_node.label)]['rel_vals']
            # In case the value is not in the dataframe
            if len(rel_val):
                new_node.relative_value = rel_val
            else:
                new_node.relative_value = 0

            # Add to node list
            new_node_list.append(new_node)
        else:
            i = 0
            for sublayer in data[sublayers].unique():
                row = r_increment * i
                # Create node instance
                new_node = CircNode([node.position[0], 0], node.label,
                                      group=node.group)
                new_node.position[1] = r + row
                rel_val = data[(data[nodes] == new_node.label) &
                               (data[sublayers] == sublayer)]['rel_vals']
                # In case the value is not in the dataframe
                if len(rel_val):
                    new_node.relative_value = rel_val
                else:
                    new_node.relative_value = 0
                i += 1
                # Add to node list
                new_node_list.append(new_node)

    return new_node_list

# %% Connection operations


def create_conns(data, node_width, nodes, rel_interval):
    conns_df = pd.DataFrame()
    conns_df[['node_1', 'node_2', 'conn_val']] = data

    # Sort by connection strength? - to plot the strongest ones first?

    # Remove duplicate - move this into the function later
    conns_df = conns_df[(conns_df.node_1) != (conns_df.node_2)]
    max_value = conns_df.conn_val.max()
    min_value = conns_df.conn_val.min()
    val_range = max_value - min_value

    # Create relativistic values for connection strengths
    conns_df.conn_val = (conns_df.conn_val - min_value) / val_range

    # Reduce by interval
    if type(rel_interval[0]) == list:
        new_conn_df = pd.DataFrame()
        for interval in rel_interval:
            int_start = conns_df.conn_val.quantile(interval[0])
            int_stop = conns_df.conn_val.quantile(interval[1])
            pd.concat([new_conn_df,
                      conns_df[((conns_df.conn_val >= int_start) &
                                (conns_df.conn_val <= int_stop))]])
    else:
        int_start = conns_df.conn_val.quantile(rel_interval[0])
        int_stop = conns_df.conn_val.quantile(rel_interval[1])
        conns_df = conns_df[((conns_df.conn_val >= int_start) &
                             (conns_df.conn_val <= int_stop))]

    # Sorth the connections by strength
    conns_df = conns_df.sort_values(by=['conn_val'], ascending=True)

    # Get number of connections and reate start and end points with jitter
    noise_max = node_width * (len(nodes)*0.001)
    rng = np.random.mtrand.RandomState(seed=0)
    conns_df['node_1_conns'] = 1
    conns_df['node_2_conns'] = 1
    for node in nodes:
        conns_df.loc[(conns_df.node_1 == node.label),
                     'node_1_conns'] = sum(
                     conns_df.node_1 == node.label) + sum(
                     conns_df.node_2 == node.label)
        conns_df.loc[(conns_df.node_1 == node.label),
                     'node_2_conns'] = sum(
                     conns_df.node_2 == node.label) + sum(
                     conns_df.node_1 == node.label)

    for conn_row in conns_df.iterrows():
        i = conn_row[0]
        start_noise = rng.uniform(-noise_max, noise_max,
                                  conns_df.loc[i, 'node_1_conns'])[0]
        conns_df.loc[i, 'start_noise'] = start_noise
        end_noise = rng.uniform(-noise_max, noise_max,
                                conns_df.loc[i, 'node_2_conns'])[-1]
        conns_df.loc[i, 'end_noise'] = end_noise

    nodes_n_con_seen = np.zeros(len(nodes))
    conn_list = []
    for conn_row in conns_df.iterrows():
        i = conn_row[0]
        row_vals = conn_row[1]

        start_idxs = [idx for idx, x in enumerate(nodes) if x.label ==
                      row_vals.node_1]
        end_idxs = [idx for idx, x in enumerate(nodes) if x.label ==
                    row_vals.node_2]
        if len(start_idxs) == 0 or len(end_idxs) == 0:
            continue
        start = start_idxs[0]
        end = end_idxs[0]
        nodes_n_con_seen[start] += 1
        nodes_n_con_seen[end] += 1

        # Create connection object
        conn = CircConn([x for x in nodes if x.label == row_vals.node_1][0],
                          [x for x in nodes if x.label == row_vals.node_2][0])
        start_noise = conns_df.loc[i, 'start_noise']
        end_noise = conns_df.loc[i, 'end_noise']
        conn.start_point = ([conn.start_node.position[0] +
                            (node_width/2) +
                            start_noise,
                            conn.start_node.position[1]])
        conn.end_point = ([conn.end_node.position[0] +
                          (node_width/2) +
                          end_noise,
                          conn.end_node.position[1]])
        conn.relative_value = conns_df.loc[i, 'conn_val']
        conn_list.append(conn)

    return conn_list



# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 23:45:40 2016

Library of circles evaluating relationships between nodes.

Ing.,Mgr. (MSc.) Jan Cimbálník
Biomedical engineering
International Clinical Research Center
St. Anne's University Hospital in Brno
Czech Republic
&
Mayo systems electrophysiology lab
Mayo Clinic
200 1st St SW
Rochester, MN
United States
"""

# %% Imports

from .utils import *

import matplotlib.pyplot as plt
import matplotlib.path as m_path
import matplotlib.patches as m_patches


# %% Connection circo
def conn_circ(nodes_1, nodes_2, conn_val, data, r, rel_interval=[0, 1],
              orderby=None, groupby=None,
              ax=None, cmap='jet', labels=True, headlayer=None,
              causality=False, codein=['color'], max_linewidth=1):
    """
    Creates circle with relationships between two nodes.

    Parameters:
    -----------
    nodes_1 - column name of the first node of the connection\n
    nodes_2 - column name of the second node of the connection\n
    conn_val - column name of the connection value\n
    data - pandas dataframe\n
    r - radius of the circle\n
    rel_interval - interval in witch the connections are displayed\n
    orderby - column name by which the nodes are ordered\n
    groupby - column name by which the nodes are grouped\n
    ax - axes to which the circle is plotted\n
    cmap - matplotlib cmap for colorcoding\n
    create_labels - wether to create node and group labels\n
    headlayer - leading layer where node positions are specified\n
    codein - list of methods for value coding (color, opacity, linewidth)\n
    max_linewidth - maximum linewidth\n

    Returns:
    --------
    ax - plot axes
    layer - layer object
    """

    # Create colormap
    colormap = plt.get_cmap(cmap)

    data.loc[:, 'rel_vals'] = 0
    if headlayer is None:
        node_list, node_width = create_node_list(nodes_1, data, r,
                                                 orderby=orderby,
                                                 groupby=groupby)
    else:
        node_list = headlayer.node_list
        node_list = reuse_nodes(node_list, nodes_1, data, r)
        node_width = headlayer.node_width

    conn_list = create_conns(data[[nodes_1, nodes_2, conn_val]],
                             node_width, node_list, rel_interval)

    # If no axis is passed, create onee
    if ax is None:
        plt.figure(facecolor='w')
        ax = plt.subplot(111, projection='polar')
        ax.spines['polar'].set_visible(False)

    circle = plt.Circle((0, 0), r, transform=ax.transData._b,
                        color="k", fill=False, alpha=1.)
    ax.add_artist(circle)

    for conn in conn_list:

        # Code relative value
        if 'color' in codein:
            conn.color = colormap(conn.relative_value)
        if 'opacity' in codein:
            conn.opacity = conn.relative_value
        if 'linewidth' in codein:
            conn.linewidth = max_linewidth * conn.relative_value

        t0 = conn.start_point[0]
        t1 = conn.end_point[0]

        verts = [(t0, r), (t0, r/2), (t1, r/2), (t1, r)]
        codes = [m_path.Path.MOVETO, m_path.Path.CURVE4,
                 m_path.Path.CURVE4, m_path.Path.LINETO]
        path = m_path.Path(verts, codes)

        patch = m_patches.PathPatch(path, fill=False, linewidth=conn.linewidth,
                                    edgecolor=conn.color, alpha=conn.opacity)

        ax.add_patch(patch)

        if causality:
            ax.arrow(conn.end_point[0], conn.end_point[1]-r/10, 0, 0,
                     head_length=r/10, head_width=0.05,
                     fc=conn.color, ec=conn.color, alpha=conn.opacity)

    # Set circle size if we do not have any previous
    if ax.get_ylim()[1] == 1:
        ax.set_rmax(r)

    if labels:
        create_labels(node_list, node_width, ax)
        if any([x.group for x in node_list]):
            create_group_labels([x for x in node_list if x.position[1] == r],
                                node_width, ax)

    # In the end create layer instance and return it
    layer = CircLayer('conn_circo', r, 0, node_list, node_width, conn_list)

    return ax, layer



# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 23:36:55 2016

Library of circles evaluating values of nodes.

Ing.,Mgr. (MSc.) Jan Cimbálník
Biomedical engineering
International Clinical Research Center
St. Anne's University Hospital in Brno
Czech Republic
&
Mayo systems electrophysiology lab
Mayo Clinic
200 1st St SW
Rochester, MN
United States
"""

# %% Imports

from .utils import *

import matplotlib.pyplot as plt

# %% The histogram of counts - do grouping - look at seaborn later

# TODO - group by - channel name in this case


def hist_circ(nodes, heat, data, r, max_height, orderby=None, groupby=None,
              ax=None, method='sum', cmap='jet', labels=True,
              headlayer=None, codein=['height']):

    """
    Creates a histogram circle.

    Parameters:
    -----------
    nodes - column name with node names\n
    heat - column name with the values for the histogram\n
    data - pandas dataframe\n
    r - radius of the circle\n
    max_height - maximum height of the histogram columns\n
    orderby - column name by which the nodes are ordered\n
    groupby - column name with node groups\n
    ax - axes to which the circle is plotted\n
    method - method by which the values in heat column are processed the optins
    are 'sum' or 'mean'\n
    cmap - matplotlib cmap for colorcoding\n
    create_labels - wether to create node and group labels\n
    headlayer - leading layer where node positions are specified\n
    codein - list of methods for histogram value coding, options are:
    'height','color','opacity'\n

    Returns:
    --------
    ax - plot axes
    layer - layer object
    """

    # Create colormap
    colormap = plt.get_cmap(cmap)

    # Order by
    if orderby is not None:
        data = data.sort_values(by=orderby)

    # Create variables for relative values
    if method == 'sum':
        max_value = data.groupby(nodes)[heat].sum().max()
        min_value = data.groupby(nodes)[heat].sum().min()
    elif method == 'mean':
        max_value = data.groupby(nodes)[heat].mean().max()
        min_value = data.groupby(nodes)[heat].mean().min()
    val_range = max_value - min_value

    # Assign relative values
    data['rel_vals'] = (data[heat] - min_value) / val_range

    # Create node list
    if headlayer is None:
        node_list, node_width = create_node_list(nodes, data, r,
                                                 orderby=orderby,
                                                 groupby=groupby)
    else:
        node_list = headlayer.node_list
        node_list = reuse_nodes(node_list, nodes, data, r, sublayers=None,
                                r_increment=0.1)
        node_width = headlayer.node_width

    if ax is None:
        plt.figure(facecolor='w')
        ax = plt.subplot(111, projection='polar')
        ax.spines['polar'].set_visible(False)

    for node in node_list:

        # Code relative value
        if 'color' in codein:
            node.color = colormap(node.relative_value)
        if 'height' in codein:
            bar_height = max_height*node.relative_value
        else:
            bar_height = max_height
        if 'opacity' in codein:
            node.opacity = node.relative_value

        # Create node in plot

        bar = ax.bar(node.position[0], bar_height, width=node_width, bottom=r,
                     color=node.color, edgecolor="None",
                     alpha=node.opacity)[0]

        node.patch = bar

        # TODO KWARGS to bar, later

    if labels:
        create_labels(node_list, node_width, ax)
        if any([x.group for x in node_list]):
            create_group_labels(node_list, node_width, ax)

    # In the end create layer instance
    layer = CircLayer('hist_circo', r, max_height, node_list, node_width)

    return ax, layer

# %% Plot the heatmap - this is colour coded histogram
# - many times - just relative values are different


def heat_map_circ(nodes, sublayers, heat, data, r, row_height, orderby=None,
                  groupby=None, ax=None, cmap='jet', labels=True,
                  headlayer=None, codein=['color']):

    # TODO - add separation and sorting later by structure for example

    """
    Creates a heat map circle.

    Parameters:
    -----------
    nodes - column name with node names\n
    sublayers - column name with rows of for the heatmap\n
    heat - column name with the values for the heatmap\n
    data - pandas dataframe\n
    r - radius of the circle\n
    row_height - height of one row of the heatmap\n
    orderby - column name by which the nodes are ordered\n
    groupby - column name with node groups\n
    ax - axes to which the circle is plotted\n
    cmap - matplotlib cmap for colorcoding\n
    create_labels - wether to create node and group labels\n
    headlayer - leading layer where node positions are specified\n
    codein - list of methods for histogram value coding, options are:
    'color','opacity'\n

    Returns:
    --------
    ax - plot axes
    layer - layer object
    """

    # Create colormap
    colormap = plt.get_cmap(cmap)

    # Order by
    if orderby is not None:
        data = data.sort_values(by=orderby)

    # Variables for relative values
    max_value = data[heat].max()
    min_value = data[heat].min()
    val_range = max_value - min_value

    # Assign relative values
    data['rel_vals'] = (data[heat] - min_value) / val_range

    # Create node list - all nodes in heatmap - more layers
#    node_list = []
#    i=r
#    for sublayer in data[sublayers].unique():
#        node_sublist, node_width = create_node_list(nodes, data, i,
#                                                    orderby = orderby,
#                                                    groupby = groupby,
#                                                    sublayers = sublayers)
#        node_list = node_list + node_sublist
#        i += row_height

    N_sublayers = len(data[sublayers].unique())
    # Create node list
    if headlayer is None:
        node_list, node_width = create_node_list(nodes, data, r,
                                                 orderby=orderby,
                                                 groupby=groupby,
                                                 sublayers=sublayers,
                                                 r_increment=row_height)
    else:
        node_list = headlayer.node_list
        node_list = reuse_nodes(node_list, nodes, data, r,
                                sublayers=sublayers, r_increment=row_height)
        node_width = headlayer.node_width

    # If no axis is passed, create one
    if ax is None:
        plt.figure(facecolor='w')
        ax = plt.subplot(111, projection='polar')
        ax.spines['polar'].set_visible(False)

    for node in node_list:

        # Code relative value
        if 'color' in codein:
            node.color = colormap(node.relative_value)
        if 'opacity' in codein:
            node.opacity = node.relative_value

        # Create node in plot
        node.color = colormap(node.relative_value)

        bar = ax.bar(node.position[0], row_height, width=node_width,
                     bottom=node.position[1], color=node.color,
                     edgecolor=node.color, alpha=node.opacity)[0]

        node.patch = bar
        # TODO KWARGS to bar, later

    # TODO kwargs for text and check if text is already there
    if labels:
        creat_labels([x for x in node_list if x.position[1] == r],
                    node_width, ax)
        if any([x.group for x in node_list]):
            create_group_labels([x for x in node_list if x.position[1] == r],
                              node_width, ax)

    # In the end create layer instance and return it
    layer = CircLayer('heat_circo', r, (N_sublayers*row_height - r),
                       node_list, node_width)

    return ax, layer



# -*- coding: utf-8 -*-
"""
Created on Thu Feb 21 23:29:55 2016

Setup file for the biosigpy package.

Ing.,Mgr. (MSc.) Jan Cimbálník
Biomedical engineering
International Clinical Research Center
St. Anne's University Hospital in Brno
Czech Republic
&
Mayo systems electrophysiology lab
Mayo Clinic
200 1st St SW
Rochester, MN
United States
"""

from setuptools import setup

setup(name='pancircs',
      version='0.2.0',
      install_requires=['pandas','matplotlib'],
      description='Package for circualar visualization of data in pandas',
      url='http://github.com/cimbi/pancircs',
      author='Jan Cimbalnik',
      author_email='jan.cimbalnik@fnusa.cz, jan.cimbalnik@mayo.edu',
      license='BSD 3.0',
      packages=['pancircs'],
      keywords='pandas circle visualization',
      classifiers=[
          'Development Status :: 2 - Pre-Alpha',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: BSD License',
          'Programming Language :: Python :: 3.4',
          'Topic :: Scientific/Engineering :: Visualization'],
      zip_safe=False)